@@ -7,11 +7,12 @@ BEGIN {
   $Gentoo::Dependency::AST::Node::Group::NotUse::AUTHORITY = 'cpan:KENTNL';
 }
 {
-  $Gentoo::Dependency::AST::Node::Group::NotUse::VERSION = '0.001000';
+  $Gentoo::Dependency::AST::Node::Group::NotUse::VERSION = '0.001001';
 }
 
 # ABSTRACT: A group of dependencies that require a C<useflag> disabled to trigger require
 
+
 use parent 'Gentoo::Dependency::AST::Node::Group::Use';
 
 1;
@@ -20,7 +21,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -28,7 +29,18 @@ Gentoo::Dependency::AST::Node::Group::NotUse - A group of dependencies that requ
 
 =head1 VERSION
 
-version 0.001000
+version 0.001001
+
+=begin MetaPOD::JSON v1.1.0
+
+{
+    "namespace":"Gentoo::Dependency::AST::Node::Group::NotUse",
+    "interface":"class",
+    "inherits":"Gentoo::Dependency::AST::Node::Group::Use"
+}
+
+
+=end MetaPOD::JSON
 
 =head1 AUTHOR
 
