@@ -6,11 +6,12 @@ BEGIN {
   $Gentoo::Dependency::AST::Node::TopLevel::AUTHORITY = 'cpan:KENTNL';
 }
 {
-  $Gentoo::Dependency::AST::Node::TopLevel::VERSION = '0.001000';
+  $Gentoo::Dependency::AST::Node::TopLevel::VERSION = '0.001001';
 }
 
 # ABSTRACT: A C<root> node that contains all other nodes
 
+
 use parent 'Gentoo::Dependency::AST::Node';
 
 sub _croak {
@@ -28,7 +29,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -36,7 +37,18 @@ Gentoo::Dependency::AST::Node::TopLevel - A C<root> node that contains all other
 
 =head1 VERSION
 
-version 0.001000
+version 0.001001
+
+=begin MetaPOD::JSON v1.1.0
+
+{
+    "namespace":"Gentoo::Dependency::AST::Node::TopLevel",
+    "interface":"class",
+    "inherits":"Gentoo::Dependency::AST::Node"
+}
+
+
+=end MetaPOD::JSON
 
 =head1 AUTHOR
 
